Learn R Programming

saebnocov (version 0.1.0)

alphabetaEB: Estimates alpha and beta parameter to obtain EB estimator

Description

Estimates alpha and beta parameter to obtain EB estimator

Usage

alphabetaEB(data.dir, pcap, method, opt, maxiter, tol)

Value

This function returns a data frame with following objects :

alpha_cap

an alpha estimator by user's choice method

beta_cap

an beta estimator by user's choice method

Arguments

data.dir

Direct estimates of the data from function pcapdir

pcap

weighted sample mean and variance from function pcapdir

method

Method to estimate alpha and beta parameter according to person(rao or claire)

opt

Method to estimate alpha and beta parameter according to the way of calculation (moment or nr)

maxiter

the Maximum iteration value

tol

Tolerance error value at iteration

Examples

Run this code
## load dataset with no weight value
data(dataEB)
temp = pcapdir(dataEB[,-c(3)])
## estimates alpha and beta parameter
## in EB estimate with Moment method by J.N.K.Rao
alphabetaEB(data.dir = temp$direst ,pcap = temp$pcap,
method = "rao", opt = "moment",maxiter = 100,tol = 0.00001)

##load dataset with weight value
data(dataEB)
temp = pcapdir(dataEB)
## estimates alpha and beta parameter
## in EB estimate with Moment method by Claire E.B.O.
alphabetaEB(data.dir = temp$direst ,pcap = temp$pcap,
method = "claire", opt = "moment",maxiter = 100,tol = 0.00001)

Run the code above in your browser using DataLab