Learn R Programming

saebnocov (version 0.1.0)

momentRao: Estimates alpha and beta parameter with Moment method by J.N.K.Rao

Description

Estimates alpha and beta parameter with Moment method by J.N.K.Rao

Usage

momentRao(data.dir, pcap)

Value

This function returns a data frame with following objects :

alpha_cap

an alpha estimator by Moment method of Claire E.B.O.

beta_cap

an beta estimator by Moment method of Claire E.B.O.

Arguments

data.dir

Direct estimates of the data from function pcapdir

pcap

weighted sample mean and variance from function pcapdir

Examples

Run this code
## load dataset with no weight value
data(dataEB)
temp = pcapdir(dataEB[,-c(3)])
momentRao(data.dir = temp$direst, pcap = temp$pcap)

##load dataset with weight value
data(dataEB)
temp = pcapdir(dataEB[,-c(3)])
momentRao(data.dir = temp$direst, pcap = temp$pcap)

Run the code above in your browser using DataLab