Learn R Programming

saebnocov (version 0.1.0)

vectorClaire: Vector g in Newton Raphson Method by Claire E.B.O.

Description

Vector g in Newton Raphson Method by Claire E.B.O.

Usage

vectorClaire(alpha, beta, p)

Value

This function returns a value of vector g.

Arguments

alpha

An alpha estimate value on iterating process

beta

A beta estimate value on iterating process

p

direct estimator or proportion value

Examples

Run this code
## load dataset with no weight value
data(dataEB)
temp = pcapdir(dataEB[,-c(3)])

## estimates alpha and beta parameter
## in EB estimate with Moment method by J.N.K.Rao
temp1 = alphabetaEB(data.dir = temp$direst ,pcap = temp$pcap,
                      method = "rao", opt = "moment",
                      maxiter = 100,tol = 0.00001)

##calculates vector g
vectorClaire(alpha = temp1$alpha_cap, beta = temp1$beta_cap, p = temp$direst$p)

Run the code above in your browser using DataLab